# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased]

## [0.1.5] - 2022-09-29

### Added

- Added `AsyncStore` for the asynchronous version of the API

### Changed

### Fixed

## [0.1.4] - 2022-09-29

### Added

### Changed

- Enhanced the Model's `__eq__` to be able to compare dictionaries containing timezone-aware datetimes

### Fixed

- Fixed invalid-type error in models with datetime errors

## [0.1.3] - 2022-09-28

### Added

- Initial release

### Changed

### Fixed
